<p align="center">
    <img
        src="https://raw.githubusercontent.com/dbt-labs/dbt/ec7dee39f793aa4f7dd3dae37282cc87664813e4/etc/dbt-logo-full.svg"
        alt="dbt logo"
        width="500"
    />
</p>

<p align="center">
    <a href="https://pypi.org/project/dbt-snowflake/">
        <img src="https://badge.fury.io/py/dbt-snowflake.svg" />
    </a>
    <a target="_blank" href="https://pypi.org/project/dbt-snowflake/" style="background:none">
        <img src="https://img.shields.io/pypi/pyversions/dbt-snowflake">
    </a>
    <a href="https://github.com/psf/black">
        <img src="https://img.shields.io/badge/code%20style-black-000000.svg" />
    </a>
    <a href="https://github.com/python/mypy">
        <img src="https://www.mypy-lang.org/static/mypy_badge.svg" />
    </a>
    <a href="https://pepy.tech/project/dbt-snowflake">
        <img src="https://static.pepy.tech/badge/dbt-snowflake/month" />
    </a>
</p>

# dbt

**[dbt](https://www.getdbt.com/)** enables data analysts and engineers to transform their data using the same practices that software engineers use to build applications.

dbt is the T in ELT. Organize, cleanse, denormalize, filter, rename, and pre-aggregate the raw data in your warehouse so that it's ready for analysis.

## dbt-snowflake

`dbt-snowflake` enables dbt to work with Snowflake.
For more information on using dbt with Snowflake, consult [the docs](https://docs.getdbt.com/docs/profile-snowflake).

# Getting started

Review the repository [README.md](../README.md) as most of that information pertains to `dbt-snowflake`.

## Contribute

- Want to help us build `dbt-snowflake`? Check out the [Contributing Guide](CONTRIBUTING.md).
